# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/ui/setup_wizard.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SetupWizard(object):
    def setupUi(self, SetupWizard):
        SetupWizard.setObjectName("SetupWizard")
        SetupWizard.resize(603, 287)
        SetupWizard.setModal(True)
        SetupWizard.setWizardStyle(QtWidgets.QWizard.ModernStyle)
        SetupWizard.setOptions(QtWidgets.QWizard.NoBackButtonOnStartPage)
        self.uiControllerWizardPage = QtWidgets.QWizardPage()
        self.uiControllerWizardPage.setObjectName("uiControllerWizardPage")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.uiControllerWizardPage)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.uiLocalControllerRadioButton = QtWidgets.QRadioButton(self.uiControllerWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiLocalControllerRadioButton.sizePolicy().hasHeightForWidth())
        self.uiLocalControllerRadioButton.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.uiLocalControllerRadioButton.setFont(font)
        self.uiLocalControllerRadioButton.setChecked(True)
        self.uiLocalControllerRadioButton.setObjectName("uiLocalControllerRadioButton")
        self.verticalLayout_4.addWidget(self.uiLocalControllerRadioButton)
        self.uiRemoteControllerRadioButton = QtWidgets.QRadioButton(self.uiControllerWizardPage)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.uiRemoteControllerRadioButton.setFont(font)
        self.uiRemoteControllerRadioButton.setObjectName("uiRemoteControllerRadioButton")
        self.verticalLayout_4.addWidget(self.uiRemoteControllerRadioButton)
        spacerItem = QtWidgets.QSpacerItem(20, 212, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem)
        SetupWizard.addPage(self.uiControllerWizardPage)
        self.uiLocalControllerWizardPage = QtWidgets.QWizardPage()
        self.uiLocalControllerWizardPage.setObjectName("uiLocalControllerWizardPage")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.uiLocalControllerWizardPage)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.uiLocalServerPathLabel = QtWidgets.QLabel(self.uiLocalControllerWizardPage)
        self.uiLocalServerPathLabel.setObjectName("uiLocalServerPathLabel")
        self.gridLayout_2.addWidget(self.uiLocalServerPathLabel, 0, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.uiLocalServerPathLineEdit = QtWidgets.QLineEdit(self.uiLocalControllerWizardPage)
        self.uiLocalServerPathLineEdit.setObjectName("uiLocalServerPathLineEdit")
        self.horizontalLayout_3.addWidget(self.uiLocalServerPathLineEdit)
        self.uiLocalServerToolButton = QtWidgets.QToolButton(self.uiLocalControllerWizardPage)
        self.uiLocalServerToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiLocalServerToolButton.setObjectName("uiLocalServerToolButton")
        self.horizontalLayout_3.addWidget(self.uiLocalServerToolButton)
        self.gridLayout_2.addLayout(self.horizontalLayout_3, 0, 1, 1, 1)
        self.uiLocalServerHostLabel = QtWidgets.QLabel(self.uiLocalControllerWizardPage)
        self.uiLocalServerHostLabel.setObjectName("uiLocalServerHostLabel")
        self.gridLayout_2.addWidget(self.uiLocalServerHostLabel, 1, 0, 1, 1)
        self.uiLocalServerHostComboBox = QtWidgets.QComboBox(self.uiLocalControllerWizardPage)
        self.uiLocalServerHostComboBox.setObjectName("uiLocalServerHostComboBox")
        self.gridLayout_2.addWidget(self.uiLocalServerHostComboBox, 1, 1, 1, 1)
        self.uiLocalServerPortLabel = QtWidgets.QLabel(self.uiLocalControllerWizardPage)
        self.uiLocalServerPortLabel.setObjectName("uiLocalServerPortLabel")
        self.gridLayout_2.addWidget(self.uiLocalServerPortLabel, 2, 0, 1, 1)
        self.uiLocalServerPortSpinBox = QtWidgets.QSpinBox(self.uiLocalControllerWizardPage)
        self.uiLocalServerPortSpinBox.setSuffix(" TCP")
        self.uiLocalServerPortSpinBox.setMaximum(65535)
        self.uiLocalServerPortSpinBox.setProperty("value", 3080)
        self.uiLocalServerPortSpinBox.setObjectName("uiLocalServerPortSpinBox")
        self.gridLayout_2.addWidget(self.uiLocalServerPortSpinBox, 2, 1, 1, 1)
        SetupWizard.addPage(self.uiLocalControllerWizardPage)
        self.uiRemoteControllerWizardPage = QtWidgets.QWizardPage()
        self.uiRemoteControllerWizardPage.setObjectName("uiRemoteControllerWizardPage")
        self.gridLayout = QtWidgets.QGridLayout(self.uiRemoteControllerWizardPage)
        self.gridLayout.setObjectName("gridLayout")
        self.label_3 = QtWidgets.QLabel(self.uiRemoteControllerWizardPage)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 0, 1, 1)
        self.uiRemoteMainServerPasswordLineEdit = QtWidgets.QLineEdit(self.uiRemoteControllerWizardPage)
        self.uiRemoteMainServerPasswordLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.uiRemoteMainServerPasswordLineEdit.setObjectName("uiRemoteMainServerPasswordLineEdit")
        self.gridLayout.addWidget(self.uiRemoteMainServerPasswordLineEdit, 3, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.uiRemoteControllerWizardPage)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 3, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.uiRemoteControllerWizardPage)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 0, 1, 1)
        self.uiRemoteMainServerUserLineEdit = QtWidgets.QLineEdit(self.uiRemoteControllerWizardPage)
        self.uiRemoteMainServerUserLineEdit.setObjectName("uiRemoteMainServerUserLineEdit")
        self.gridLayout.addWidget(self.uiRemoteMainServerUserLineEdit, 2, 1, 1, 1)
        self.uiRemoteMainServerPortSpinBox = QtWidgets.QSpinBox(self.uiRemoteControllerWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiRemoteMainServerPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiRemoteMainServerPortSpinBox.setSizePolicy(sizePolicy)
        self.uiRemoteMainServerPortSpinBox.setMaximum(65535)
        self.uiRemoteMainServerPortSpinBox.setProperty("value", 3080)
        self.uiRemoteMainServerPortSpinBox.setObjectName("uiRemoteMainServerPortSpinBox")
        self.gridLayout.addWidget(self.uiRemoteMainServerPortSpinBox, 1, 1, 1, 1)
        self.uiRemoteMainServerHostLineEdit = QtWidgets.QLineEdit(self.uiRemoteControllerWizardPage)
        self.uiRemoteMainServerHostLineEdit.setObjectName("uiRemoteMainServerHostLineEdit")
        self.gridLayout.addWidget(self.uiRemoteMainServerHostLineEdit, 0, 1, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.uiRemoteControllerWizardPage)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 2, 0, 1, 1)
        SetupWizard.addPage(self.uiRemoteControllerWizardPage)
        self.uiSummaryWizardPage = QtWidgets.QWizardPage()
        self.uiSummaryWizardPage.setObjectName("uiSummaryWizardPage")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.uiSummaryWizardPage)
        self.verticalLayout.setObjectName("verticalLayout")
        self.uiSummaryTreeWidget = QtWidgets.QTreeWidget(self.uiSummaryWizardPage)
        self.uiSummaryTreeWidget.setRootIsDecorated(False)
        self.uiSummaryTreeWidget.setObjectName("uiSummaryTreeWidget")
        self.uiSummaryTreeWidget.header().setVisible(False)
        self.verticalLayout.addWidget(self.uiSummaryTreeWidget)
        self.uiShowCheckBox = QtWidgets.QCheckBox(self.uiSummaryWizardPage)
        self.uiShowCheckBox.setChecked(True)
        self.uiShowCheckBox.setObjectName("uiShowCheckBox")
        self.verticalLayout.addWidget(self.uiShowCheckBox)
        SetupWizard.addPage(self.uiSummaryWizardPage)

        self.retranslateUi(SetupWizard)
        QtCore.QMetaObject.connectSlotsByName(SetupWizard)

    def retranslateUi(self, SetupWizard):
        _translate = QtCore.QCoreApplication.translate
        SetupWizard.setWindowTitle(_translate("SetupWizard", "Setup Wizard"))
        self.uiControllerWizardPage.setTitle(_translate("SetupWizard", "Controller"))
        self.uiControllerWizardPage.setSubTitle(_translate("SetupWizard", "Please select an option to connect to the GNS3 controller"))
        self.uiLocalControllerRadioButton.setToolTip(_translate("SetupWizard", "A local controller runs on the same machine as this graphical interface"))
        self.uiLocalControllerRadioButton.setText(_translate("SetupWizard", "Start and connect to a local controller (Linux only)"))
        self.uiRemoteControllerRadioButton.setToolTip(_translate("SetupWizard", "A remote controller can run in a Virtual Machine (VM) or on a remote server"))
        self.uiRemoteControllerRadioButton.setText(_translate("SetupWizard", "Connect to a remote controller"))
        self.uiLocalControllerWizardPage.setTitle(_translate("SetupWizard", "Local controller configuration"))
        self.uiLocalControllerWizardPage.setSubTitle(_translate("SetupWizard", "Please configure the following local server settings"))
        self.uiLocalServerPathLabel.setText(_translate("SetupWizard", "Server path:"))
        self.uiLocalServerToolButton.setText(_translate("SetupWizard", "&Browse..."))
        self.uiLocalServerHostLabel.setText(_translate("SetupWizard", "Host binding:"))
        self.uiLocalServerPortLabel.setText(_translate("SetupWizard", "Port:"))
        self.uiRemoteControllerWizardPage.setTitle(_translate("SetupWizard", "Remote controller"))
        self.uiRemoteControllerWizardPage.setSubTitle(_translate("SetupWizard", "Please configure the settings to connect to a remote GNS3 controller"))
        self.label_3.setText(_translate("SetupWizard", "Host:"))
        self.label_6.setText(_translate("SetupWizard", "Password:"))
        self.label_4.setText(_translate("SetupWizard", "Port:"))
        self.uiRemoteMainServerPortSpinBox.setSuffix(_translate("SetupWizard", " TCP"))
        self.label_5.setText(_translate("SetupWizard", "Username:"))
        self.uiSummaryWizardPage.setTitle(_translate("SetupWizard", "Summary"))
        self.uiSummaryWizardPage.setSubTitle(_translate("SetupWizard", "The controller has been configured, please see the summary of the settings below"))
        self.uiSummaryTreeWidget.headerItem().setText(0, _translate("SetupWizard", "1"))
        self.uiSummaryTreeWidget.headerItem().setText(1, _translate("SetupWizard", "2"))
        self.uiShowCheckBox.setText(_translate("SetupWizard", "Don\'t show this setup wizard again"))
from . import resources_rc
