# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/modules/qemu/ui/qemu_vm_wizard.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_QemuVMWizard(object):
    def setupUi(self, QemuVMWizard):
        QemuVMWizard.setObjectName("QemuVMWizard")
        QemuVMWizard.resize(647, 452)
        QemuVMWizard.setModal(True)
        self.uiServerWizardPage = QtWidgets.QWizardPage()
        self.uiServerWizardPage.setObjectName("uiServerWizardPage")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.uiServerWizardPage)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.uiServerTypeGroupBox = QtWidgets.QGroupBox(self.uiServerWizardPage)
        self.uiServerTypeGroupBox.setObjectName("uiServerTypeGroupBox")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.uiServerTypeGroupBox)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.uiRemoteRadioButton = QtWidgets.QRadioButton(self.uiServerTypeGroupBox)
        self.uiRemoteRadioButton.setChecked(True)
        self.uiRemoteRadioButton.setObjectName("uiRemoteRadioButton")
        self.verticalLayout_5.addWidget(self.uiRemoteRadioButton)
        self.uiVMRadioButton = QtWidgets.QRadioButton(self.uiServerTypeGroupBox)
        self.uiVMRadioButton.setObjectName("uiVMRadioButton")
        self.verticalLayout_5.addWidget(self.uiVMRadioButton)
        self.uiLocalRadioButton = QtWidgets.QRadioButton(self.uiServerTypeGroupBox)
        self.uiLocalRadioButton.setObjectName("uiLocalRadioButton")
        self.verticalLayout_5.addWidget(self.uiLocalRadioButton)
        self.verticalLayout_3.addWidget(self.uiServerTypeGroupBox)
        self.uiRemoteServersGroupBox = QtWidgets.QGroupBox(self.uiServerWizardPage)
        self.uiRemoteServersGroupBox.setObjectName("uiRemoteServersGroupBox")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.uiRemoteServersGroupBox)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.uiRemoteServersLabel = QtWidgets.QLabel(self.uiRemoteServersGroupBox)
        self.uiRemoteServersLabel.setObjectName("uiRemoteServersLabel")
        self.gridLayout_7.addWidget(self.uiRemoteServersLabel, 0, 0, 1, 1)
        self.uiRemoteServersComboBox = QtWidgets.QComboBox(self.uiRemoteServersGroupBox)
        self.uiRemoteServersComboBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiRemoteServersComboBox.sizePolicy().hasHeightForWidth())
        self.uiRemoteServersComboBox.setSizePolicy(sizePolicy)
        self.uiRemoteServersComboBox.setObjectName("uiRemoteServersComboBox")
        self.gridLayout_7.addWidget(self.uiRemoteServersComboBox, 0, 1, 1, 1)
        self.verticalLayout_3.addWidget(self.uiRemoteServersGroupBox)
        QemuVMWizard.addPage(self.uiServerWizardPage)
        self.uiNameWizardPage = QtWidgets.QWizardPage()
        self.uiNameWizardPage.setObjectName("uiNameWizardPage")
        self.gridLayout = QtWidgets.QGridLayout(self.uiNameWizardPage)
        self.gridLayout.setObjectName("gridLayout")
        self.uiNameLabel = QtWidgets.QLabel(self.uiNameWizardPage)
        self.uiNameLabel.setObjectName("uiNameLabel")
        self.gridLayout.addWidget(self.uiNameLabel, 0, 0, 1, 1)
        self.uiNameLineEdit = QtWidgets.QLineEdit(self.uiNameWizardPage)
        self.uiNameLineEdit.setObjectName("uiNameLineEdit")
        self.gridLayout.addWidget(self.uiNameLineEdit, 0, 1, 1, 1)
        QemuVMWizard.addPage(self.uiNameWizardPage)
        self.uiPlatformMemoryWizardPage = QtWidgets.QWizardPage()
        self.uiPlatformMemoryWizardPage.setObjectName("uiPlatformMemoryWizardPage")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.uiPlatformMemoryWizardPage)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.uiQemuPlatformLabel = QtWidgets.QLabel(self.uiPlatformMemoryWizardPage)
        self.uiQemuPlatformLabel.setObjectName("uiQemuPlatformLabel")
        self.gridLayout_2.addWidget(self.uiQemuPlatformLabel, 0, 0, 1, 1)
        self.uiQemuPlatformComboBox = QtWidgets.QComboBox(self.uiPlatformMemoryWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiQemuPlatformComboBox.sizePolicy().hasHeightForWidth())
        self.uiQemuPlatformComboBox.setSizePolicy(sizePolicy)
        self.uiQemuPlatformComboBox.setObjectName("uiQemuPlatformComboBox")
        self.gridLayout_2.addWidget(self.uiQemuPlatformComboBox, 0, 1, 1, 1)
        self.uiRamLabel = QtWidgets.QLabel(self.uiPlatformMemoryWizardPage)
        self.uiRamLabel.setObjectName("uiRamLabel")
        self.gridLayout_2.addWidget(self.uiRamLabel, 1, 0, 1, 1)
        self.uiRamSpinBox = QtWidgets.QSpinBox(self.uiPlatformMemoryWizardPage)
        self.uiRamSpinBox.setMinimum(32)
        self.uiRamSpinBox.setMaximum(65535)
        self.uiRamSpinBox.setProperty("value", 256)
        self.uiRamSpinBox.setObjectName("uiRamSpinBox")
        self.gridLayout_2.addWidget(self.uiRamSpinBox, 1, 1, 1, 1)
        QemuVMWizard.addPage(self.uiPlatformMemoryWizardPage)
        self.uiConsoleTypeWizardPage = QtWidgets.QWizardPage()
        self.uiConsoleTypeWizardPage.setObjectName("uiConsoleTypeWizardPage")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.uiConsoleTypeWizardPage)
        self.verticalLayout.setObjectName("verticalLayout")
        self.uiQemuConsoleTypeComboBox = QtWidgets.QComboBox(self.uiConsoleTypeWizardPage)
        self.uiQemuConsoleTypeComboBox.setObjectName("uiQemuConsoleTypeComboBox")
        self.uiQemuConsoleTypeComboBox.addItem("")
        self.uiQemuConsoleTypeComboBox.addItem("")
        self.uiQemuConsoleTypeComboBox.addItem("")
        self.uiQemuConsoleTypeComboBox.addItem("")
        self.uiQemuConsoleTypeComboBox.addItem("")
        self.verticalLayout.addWidget(self.uiQemuConsoleTypeComboBox)
        self.label = QtWidgets.QLabel(self.uiConsoleTypeWizardPage)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        QemuVMWizard.addPage(self.uiConsoleTypeWizardPage)
        self.uiDiskWizardPage = QtWidgets.QWizardPage()
        self.uiDiskWizardPage.setObjectName("uiDiskWizardPage")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.uiDiskWizardPage)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.uiHdaDiskExistingImageRadioButton = QtWidgets.QRadioButton(self.uiDiskWizardPage)
        self.uiHdaDiskExistingImageRadioButton.setChecked(True)
        self.uiHdaDiskExistingImageRadioButton.setObjectName("uiHdaDiskExistingImageRadioButton")
        self.horizontalLayout_3.addWidget(self.uiHdaDiskExistingImageRadioButton)
        self.uiNewImageRadioButton_2 = QtWidgets.QRadioButton(self.uiDiskWizardPage)
        self.uiNewImageRadioButton_2.setChecked(False)
        self.uiNewImageRadioButton_2.setObjectName("uiNewImageRadioButton_2")
        self.horizontalLayout_3.addWidget(self.uiNewImageRadioButton_2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.gridLayout_3.addLayout(self.horizontalLayout_3, 0, 0, 1, 1)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.uiHdaDiskImageLabel = QtWidgets.QLabel(self.uiDiskWizardPage)
        self.uiHdaDiskImageLabel.setObjectName("uiHdaDiskImageLabel")
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageLabel)
        self.uiHdaDiskImageListComboBox = QtWidgets.QComboBox(self.uiDiskWizardPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiHdaDiskImageListComboBox.sizePolicy().hasHeightForWidth())
        self.uiHdaDiskImageListComboBox.setSizePolicy(sizePolicy)
        self.uiHdaDiskImageListComboBox.setObjectName("uiHdaDiskImageListComboBox")
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageListComboBox)
        self.uiHdaDiskImageLineEdit = QtWidgets.QLineEdit(self.uiDiskWizardPage)
        self.uiHdaDiskImageLineEdit.setObjectName("uiHdaDiskImageLineEdit")
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageLineEdit)
        self.uiHdaDiskImageToolButton = QtWidgets.QToolButton(self.uiDiskWizardPage)
        self.uiHdaDiskImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiHdaDiskImageToolButton.setObjectName("uiHdaDiskImageToolButton")
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageToolButton)
        self.uiHdaDiskImageCreateToolButton = QtWidgets.QToolButton(self.uiDiskWizardPage)
        self.uiHdaDiskImageCreateToolButton.setObjectName("uiHdaDiskImageCreateToolButton")
        self.horizontalLayout_8.addWidget(self.uiHdaDiskImageCreateToolButton)
        self.gridLayout_3.addLayout(self.horizontalLayout_8, 1, 0, 1, 1)
        QemuVMWizard.addPage(self.uiDiskWizardPage)
        self.uiInitrdKernelImageWizardPage = QtWidgets.QWizardPage()
        self.uiInitrdKernelImageWizardPage.setObjectName("uiInitrdKernelImageWizardPage")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.uiInitrdKernelImageWizardPage)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.uiLinuxExistingImageRadioButton = QtWidgets.QRadioButton(self.uiInitrdKernelImageWizardPage)
        self.uiLinuxExistingImageRadioButton.setChecked(True)
        self.uiLinuxExistingImageRadioButton.setObjectName("uiLinuxExistingImageRadioButton")
        self.horizontalLayout_7.addWidget(self.uiLinuxExistingImageRadioButton)
        self.uiNewImageRadioButton_4 = QtWidgets.QRadioButton(self.uiInitrdKernelImageWizardPage)
        self.uiNewImageRadioButton_4.setChecked(False)
        self.uiNewImageRadioButton_4.setObjectName("uiNewImageRadioButton_4")
        self.horizontalLayout_7.addWidget(self.uiNewImageRadioButton_4)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem2)
        self.gridLayout_4.addLayout(self.horizontalLayout_7, 0, 0, 1, 1)
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.uiInitrdImageListComboBox = QtWidgets.QComboBox(self.uiInitrdKernelImageWizardPage)
        self.uiInitrdImageListComboBox.setObjectName("uiInitrdImageListComboBox")
        self.horizontalLayout_11.addWidget(self.uiInitrdImageListComboBox)
        self.uiInitrdImageLineEdit = QtWidgets.QLineEdit(self.uiInitrdKernelImageWizardPage)
        self.uiInitrdImageLineEdit.setObjectName("uiInitrdImageLineEdit")
        self.horizontalLayout_11.addWidget(self.uiInitrdImageLineEdit)
        self.uiInitrdImageToolButton = QtWidgets.QToolButton(self.uiInitrdKernelImageWizardPage)
        self.uiInitrdImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiInitrdImageToolButton.setObjectName("uiInitrdImageToolButton")
        self.horizontalLayout_11.addWidget(self.uiInitrdImageToolButton)
        self.formLayout_2.setLayout(0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_11)
        self.uiKernelImageLabel = QtWidgets.QLabel(self.uiInitrdKernelImageWizardPage)
        self.uiKernelImageLabel.setObjectName("uiKernelImageLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.uiKernelImageLabel)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.uiKernelImageListComboBox = QtWidgets.QComboBox(self.uiInitrdKernelImageWizardPage)
        self.uiKernelImageListComboBox.setObjectName("uiKernelImageListComboBox")
        self.horizontalLayout_14.addWidget(self.uiKernelImageListComboBox)
        self.uiKernelImageLineEdit = QtWidgets.QLineEdit(self.uiInitrdKernelImageWizardPage)
        self.uiKernelImageLineEdit.setObjectName("uiKernelImageLineEdit")
        self.horizontalLayout_14.addWidget(self.uiKernelImageLineEdit)
        self.uiKernelImageToolButton = QtWidgets.QToolButton(self.uiInitrdKernelImageWizardPage)
        self.uiKernelImageToolButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.uiKernelImageToolButton.setObjectName("uiKernelImageToolButton")
        self.horizontalLayout_14.addWidget(self.uiKernelImageToolButton)
        self.formLayout_2.setLayout(1, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_14)
        self.uiInitrdLabel = QtWidgets.QLabel(self.uiInitrdKernelImageWizardPage)
        self.uiInitrdLabel.setObjectName("uiInitrdLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.uiInitrdLabel)
        self.gridLayout_4.addLayout(self.formLayout_2, 1, 0, 1, 1)
        QemuVMWizard.addPage(self.uiInitrdKernelImageWizardPage)

        self.retranslateUi(QemuVMWizard)
        QtCore.QMetaObject.connectSlotsByName(QemuVMWizard)
        QemuVMWizard.setTabOrder(self.uiNameLineEdit, self.uiQemuPlatformComboBox)
        QemuVMWizard.setTabOrder(self.uiQemuPlatformComboBox, self.uiRamSpinBox)
        QemuVMWizard.setTabOrder(self.uiRamSpinBox, self.uiHdaDiskImageLineEdit)
        QemuVMWizard.setTabOrder(self.uiHdaDiskImageLineEdit, self.uiHdaDiskImageToolButton)

    def retranslateUi(self, QemuVMWizard):
        _translate = QtCore.QCoreApplication.translate
        QemuVMWizard.setWindowTitle(_translate("QemuVMWizard", "New QEMU VM template"))
        self.uiServerWizardPage.setTitle(_translate("QemuVMWizard", "Server"))
        self.uiServerWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a server type to run the QEMU VM."))
        self.uiServerTypeGroupBox.setTitle(_translate("QemuVMWizard", "Server type"))
        self.uiRemoteRadioButton.setText(_translate("QemuVMWizard", "Run this Qemu VM on a remote computer"))
        self.uiVMRadioButton.setText(_translate("QemuVMWizard", "Run this Qemu VM on the GNS3 VM"))
        self.uiLocalRadioButton.setText(_translate("QemuVMWizard", "Run this Qemu VM on my local computer"))
        self.uiRemoteServersGroupBox.setTitle(_translate("QemuVMWizard", "Remote server"))
        self.uiRemoteServersLabel.setText(_translate("QemuVMWizard", "Run on:"))
        self.uiNameWizardPage.setTitle(_translate("QemuVMWizard", "QEMU VM name"))
        self.uiNameWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a descriptive name for your new QEMU virtual machine."))
        self.uiNameLabel.setText(_translate("QemuVMWizard", "Name:"))
        self.uiPlatformMemoryWizardPage.setTitle(_translate("QemuVMWizard", "QEMU platform and memory"))
        self.uiPlatformMemoryWizardPage.setSubTitle(_translate("QemuVMWizard", "Please select the platform and check the virtual machine has enough memory to work."))
        self.uiQemuPlatformLabel.setText(_translate("QemuVMWizard", "Platform:"))
        self.uiRamLabel.setText(_translate("QemuVMWizard", "RAM:"))
        self.uiRamSpinBox.setSuffix(_translate("QemuVMWizard", " MB"))
        self.uiConsoleTypeWizardPage.setTitle(_translate("QemuVMWizard", "Console type"))
        self.uiConsoleTypeWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose the console type. Telnet will connect to the serial console of the machine. VNC will connect to graphical output of the machine."))
        self.uiQemuConsoleTypeComboBox.setItemText(0, _translate("QemuVMWizard", "telnet"))
        self.uiQemuConsoleTypeComboBox.setItemText(1, _translate("QemuVMWizard", "vnc"))
        self.uiQemuConsoleTypeComboBox.setItemText(2, _translate("QemuVMWizard", "spice"))
        self.uiQemuConsoleTypeComboBox.setItemText(3, _translate("QemuVMWizard", "spice+agent"))
        self.uiQemuConsoleTypeComboBox.setItemText(4, _translate("QemuVMWizard", "none"))
        self.label.setText(_translate("QemuVMWizard", "Note: You don\'t need to install anything on the VM itself."))
        self.uiDiskWizardPage.setTitle(_translate("QemuVMWizard", "Disk image"))
        self.uiDiskWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a base disk image for your virtual machine."))
        self.uiHdaDiskExistingImageRadioButton.setText(_translate("QemuVMWizard", "Existing image"))
        self.uiNewImageRadioButton_2.setText(_translate("QemuVMWizard", "New Image"))
        self.uiHdaDiskImageLabel.setText(_translate("QemuVMWizard", "Disk image (hda):"))
        self.uiHdaDiskImageToolButton.setText(_translate("QemuVMWizard", "&Browse..."))
        self.uiHdaDiskImageCreateToolButton.setText(_translate("QemuVMWizard", "&Create"))
        self.uiInitrdKernelImageWizardPage.setTitle(_translate("QemuVMWizard", "Linux boot specific settings"))
        self.uiInitrdKernelImageWizardPage.setSubTitle(_translate("QemuVMWizard", "Please choose a initrd and a kernel image."))
        self.uiLinuxExistingImageRadioButton.setText(_translate("QemuVMWizard", "Existing image"))
        self.uiNewImageRadioButton_4.setText(_translate("QemuVMWizard", "New Image"))
        self.uiInitrdImageToolButton.setText(_translate("QemuVMWizard", "&Browse..."))
        self.uiKernelImageLabel.setText(_translate("QemuVMWizard", "Kernel image (vmlinuz):"))
        self.uiKernelImageToolButton.setText(_translate("QemuVMWizard", "&Browse..."))
        self.uiInitrdLabel.setText(_translate("QemuVMWizard", "Initial RAM disk (initrd):"))
